@@ -57,7 +57,7 @@ void AboutWindow::Init()
     delete file;
 }
 
-void AboutWindow::resizeEvent(QResizeEvent* event)
+void AboutWindow::resizeEvent(QResizeEvent*)
 {
     //Update license text to let TextEditAutoResizer resize the QTextEdit
     ui->txtLicense->setHtml(ui->txtLicense->toHtml());
