@@ -15,7 +15,7 @@ void CommonStatic::ErrorMessage(QWidget* parent, QString message)
 #ifdef Q_WS_MAEMO_5
     QMaemo5InformationBox* box = new QMaemo5InformationBox(parent);
     QObject::connect(box, SIGNAL(clicked()), box, SLOT(accept()));
-    box->setStyleSheet("background: white; color: red; opacity: 223;");
+    //box->setStyleSheet("background: white; color: red; opacity: 223;");
     box->setTimeout(-1);
 
     QLabel* text = new QLabel(box);
@@ -37,7 +37,7 @@ void CommonStatic::InfoMessage(QWidget* parent, QString message)
 #ifdef Q_WS_MAEMO_5
     QMaemo5InformationBox* box = new QMaemo5InformationBox(parent);
     QObject::connect(box, SIGNAL(clicked()), box, SLOT(accept()));
-    box->setStyleSheet("background: white; color: red; opacity: 223;");
+    //box->setStyleSheet("background: white; color: red; opacity: 223;");
 
     QLabel* text = new QLabel(box);
     text->setText(message);
@@ -69,6 +69,16 @@ QString CommonStatic::GetHomeFolder()
 #endif
 }
 
+QString CommonStatic::GetSettingsFolder()
+{
+    return QString("%1/.vodafone190").arg(CommonStatic::GetHomeFolder());
+}
+
+QString CommonStatic::GetStylesheetFolder()
+{
+    return QString("%1/stylesheets").arg(GetSettingsFolder());
+}
+
 QString CommonStatic::FormatKBytes(int kbytes)
 {
     float tKb = (float)kbytes;
@@ -90,3 +100,27 @@ bool CommonStatic::IsMouseOver(QWidget* w)
         return true;
     return false;
 }
+
+void CommonStatic::SetDefaultStylesheet()
+{
+    SetStylesheet(":/stylesheets/Default.css");
+}
+
+void CommonStatic::SetStylesheet(QString fileName)
+{
+    QFile* file = new QFile(fileName);
+    if (file->open(QIODevice::ReadOnly | QIODevice::Text)){
+        QByteArray data = file->readAll();
+        QString styleSheet(data);
+        qApp->setStyleSheet(styleSheet);
+        file->close();
+    }
+    delete file;
+}
+
+
+QList<ContactWidget*> CommonStatic::ContactsWidget;
+void CommonStatic::LoadContactsCache()
+{
+
+}
