@@ -43,7 +43,7 @@ ContactsWindow::ContactsWindow(QWidget *parent) :
         ui->scrollAreaWidgetContents->setLayout(layout);
         layout->setAlignment(Qt::AlignTop);
         layout->setSpacing(0);
-        layout->setMargin(3);
+        layout->setContentsMargins(3,3,3,3);
     }
 
     ui->txtCerca->grabKeyboard();
@@ -80,14 +80,14 @@ void ContactsWindow::FillContactsList()
         man = new QContactManager(availableManagers.first());
         availableManagers.removeFirst();
 
-        contacts = man->contacts();
-        if (!contacts.isEmpty()) {
-            availableManagers.clear();
-            break;
-        } else {
+        contacts.append(man->contacts());
+        //if (!contacts.isEmpty()) {
+        //    availableManagers.clear();
+        //    break;
+        //} else {
             delete man;
             man = NULL;
-        }
+        //}
     }
 
     if (!man)
@@ -118,7 +118,7 @@ void ContactsWindow::FillContactsList()
     man = NULL;
 #else
     // Windows implementation (read a phonebook from file)
-    QString book = QString("%1/contacts.conf").arg(QCoreApplication::applicationDirPath());
+    QString book = QString("%1/contacts.conf").arg(CommonStatic::GetSettingsFolder());
     if (!QFile::exists(book))
         return;
 
