@@ -14,17 +14,18 @@ public:
     QString Class;
     QString Code;
 
+    QString Unita;
     int SogliaDisplayType;
-    int Soglia;
-    int Utilizzato;
-    int Residuo;
-    int Scatto;
+    float Soglia;
+    float Utilizzato;
+    float Residuo;
+    float Scatto;
     QString DimensioneScatto;
     QDate Periodo;
     QDate DataUtile;
 
     QString ToString();
-    void FromString(QString string);
+    bool FromString(QString string);
 };
 
 #endif // COUNTER_H
