@@ -25,12 +25,14 @@ MainWindow::MainWindow(QWidget *parent) :
     m_WaitIcon = new QMovie(":/images/wait.gif");
     m_WaitIcon->setScaledSize(QSize(40, 40));
 
+    m_MainMenu = NULL;
 #ifdef Q_OS_SYMBIAN
     QMenuBar *menu = menuBar();
     ui->lblPuntiD->setText(tr("P. Vodafone One"));
     ui->lblScadenzaD->setText(tr("P. in Scadenza"));
 #else
     QMenu *menu = menuBar()->addMenu(tr("Vodafone 190"));
+    m_MainMenu = menu;
 #endif
     m_SettingsAction = new QAction(tr("Impostazioni"), this);
     connect(m_SettingsAction, SIGNAL(triggered()), this, SLOT(SettingsSlot()));
@@ -65,6 +67,14 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 #endif
 
+    if (ui->frmContatori->layout() == NULL){
+        QVBoxLayout* layout = new QVBoxLayout(ui->frmContatori);
+        layout->setContentsMargins(9, 3, 6, 6);
+        layout->setSpacing(3);
+        layout->setAlignment(Qt::AlignTop);
+        ui->frmContatori->setLayout(layout);
+    }
+
     if (!m_Settings->Load())
         m_NoSettings = true;
     else if (m_Settings->ShowLastData){
@@ -74,17 +84,20 @@ MainWindow::MainWindow(QWidget *parent) :
         ui->lblPunti->setText(QString("%1").arg(m_Settings->LastSaldoPunti->Punti));
         ui->lblScadenza->setText(QString("%1 %2").arg(m_Settings->LastSaldoPunti->PuntiInScadenza).arg(m_Settings->LastSaldoPunti->Scadenza.toString("dd/MM/yyyy")).trimmed());
 
-        if (ui->frmContatori->layout() == NULL){
-            QVBoxLayout* layout = new QVBoxLayout(ui->frmContatori);
-            layout->setContentsMargins(9, 3, 9, 9);
-            ui->frmContatori->setLayout(layout);
-        }
-        foreach (Counter* c, *m_Settings->LastCounters){
-            CounterWidget* w = new CounterWidget(this, c, m_Settings);
-            ui->frmContatori->layout()->addWidget(w);
-        }
+        m_Counters = new QList<Counter*>(*m_Settings->LastCounters);
+        RefreshCounterWidgets();
     }
 
+    //Apply stylesheet:
+    if (m_NoSettings || m_Settings->StyleSheetName == "Default")
+        CommonStatic::SetDefaultStylesheet();
+    else if (m_Settings->StyleSheetName == "System")
+        qApp->setStyleSheet("");
+    else{
+        QString filename = QString("%1/%2.css").arg(CommonStatic::GetStylesheetFolder())
+                                               .arg(m_Settings->StyleSheetName);
+        CommonStatic::SetStylesheet(filename);
+    }
 }
 
 MainWindow::~MainWindow()
@@ -100,13 +113,13 @@ void MainWindow::Init()
     m_UpdateAction->setEnabled(false);
 
     m_Timer = new QTimer();
-    m_Timer->setInterval(1000);
+    m_Timer->setInterval(500);
     m_Timer->setSingleShot(true);
     connect(m_Timer, SIGNAL(timeout()), this, SLOT(TimerSlot()));
     m_Timer->start();
 }
 
-void MainWindow::closeEvent(QCloseEvent *event)
+void MainWindow::closeEvent(QCloseEvent *)
 {
     m_Closing = true;
     m_Vodafone->AbortRequest();
@@ -122,7 +135,7 @@ void MainWindow::TimerSlot()
     if (m_NoSettings)
         SettingsSlot();
 
-    m_Vodafone->SetCredentials(m_Settings->Username, m_Settings->Password, false);
+    m_Vodafone->SetCredentials(m_Settings->Username, m_Settings->Password);
     m_Vodafone->DebugXml = m_Settings->LogXml;
 
     if (!m_Settings->Username.isEmpty() && !m_Settings->Password.isEmpty())
@@ -135,17 +148,33 @@ void MainWindow::SettingsSlot()
 {
     QString user = m_Settings->Username;
     QString pwd = m_Settings->Password;
+    QString style = m_Settings->StyleSheetName;
+    bool std = m_Settings->ShowStandardCounters;
+
     SettingsWindow* frm = new SettingsWindow(this, m_Settings);
 #if defined(Q_OS_SYMBIAN)
     frm->showMaximized();
 #endif
     if (frm->exec() == QDialog::Accepted){
         m_Vodafone->DebugXml = m_Settings->LogXml;
-        if (!m_NoSettings && (m_Settings->Username != user || m_Settings->Password != pwd)){
+        if (!m_NoSettings &&
+            (m_Settings->Username != user || m_Settings->Password != pwd || m_Settings->ShowStandardCounters != std)){
             m_Vodafone->SetCredentials(m_Settings->Username, m_Settings->Password);
             Update();
+        }        
+
+        //Recreate counterWidgets on style change (with default stylesheet progressbare
+        //are not correclty update)
+        if (m_Settings->StyleSheetName != style)
+            RefreshCounterWidgets();
+
+        for (int i=0; i<ui->frmContatori->layout()->count(); i++){
+            QLayoutItem *child = ui->frmContatori->layout()->itemAt(i);
+            CounterWidget* w = (CounterWidget*)child->widget();
+            w->SetPercentageVisible(m_Settings->ShowPercentage);
         }
     }
+    delete frm;
     m_NoSettings = false;
 }
 
@@ -159,6 +188,8 @@ void MainWindow::AboutSlot()
 #endif
     frm->Init();
     frm->exec();
+
+    delete frm;
 }
 
 void MainWindow::QuitSlot()
@@ -184,15 +215,22 @@ void MainWindow::SelectSIMSlot()
                 Update();
         }
     }
+    delete frm;
 }
 
 void MainWindow::SmsSlot()
 {
-    SmsWindow* frm = new SmsWindow(this, m_Vodafone);
+    SmsWindow* frm = new SmsWindow(this, m_Vodafone, m_Settings);
 #if defined(Q_OS_SYMBIAN)
     frm->showMaximized();
 #endif
     frm->exec();
+    delete frm;
+}
+
+bool counterToAscending(const Counter* s1 , const Counter* s2)
+{
+    return s1->Type < s2->Type;
 }
 
 void MainWindow::Update()
@@ -216,8 +254,14 @@ void MainWindow::Update()
 
         ui->btnSMS->setEnabled(true);
 
+        if (m_Vodafone->GetSims().count() > 1){
+#ifdef Q_WS_MAEMO_5
+            m_MainMenu->setTitle(m_Vodafone->GetCurrentSim());
+#else
+            this->setWindowTitle(m_Vodafone->GetCurrentSim());
+#endif
+        }
         float credito = 0;
-
         if (m_Vodafone->GetCurrentSimType() == VodafoneWidget::SimRicaricabile){
             ui->lblCreditoResiduoD->setText(tr("Credito Residuo"));
             credito = m_Vodafone->GetCredito(&valuta);
@@ -246,22 +290,17 @@ void MainWindow::Update()
         m_Settings->LastValuta = valuta;
         m_Settings->LastSaldoPunti = punti;
 
-        m_Counters = m_Vodafone->GetListaContatori();
+        m_Counters = m_Vodafone->GetListaContatori(m_Settings->ShowStandardCounters);
         if (m_Closing)
             return;
 
-        if (ui->frmContatori->layout() == NULL){
-            QVBoxLayout* layout = new QVBoxLayout(ui->frmContatori);
-            layout->setContentsMargins(9, 3, 9, 9);
-            ui->frmContatori->setLayout(layout);
-        }else{
-            QLayoutItem *child;
-            while ((child = ui->frmContatori->layout()->takeAt(0)) != 0) {
-                delete child->widget();
-                delete child;
-            }
+        QLayoutItem *child;
+        while ((child = ui->frmContatori->layout()->takeAt(0)) != 0) {
+            delete child->widget();
+            delete child;
         }
 
+        qSort(m_Counters->begin() , m_Counters->end(), counterToAscending );
         foreach(Counter* c, *m_Counters){
             bool res = m_Vodafone->GetDettaglioContatore(c);
             if (m_Closing)
@@ -291,21 +330,26 @@ void MainWindow::Update()
 #endif
 }
 
+void MainWindow::RefreshCounterWidgets()
+{
+    QLayoutItem *child;
+    while ((child = ui->frmContatori->layout()->takeAt(0)) != 0) {
+        delete child->widget();
+        delete child;
+    }
+
+    if (m_Counters){
+        foreach(Counter* c, *m_Counters){
+            CounterWidget* w = new CounterWidget(this, c, m_Settings);
+            ui->frmContatori->layout()->addWidget(w);
+        }
+    }
+}
+
 void MainWindow::OrientationChanged()
 {
     if (ui->frmContatori->layout() != NULL){
-        QLayoutItem *child;
-        while ((child = ui->frmContatori->layout()->takeAt(0)) != 0) {
-            delete child->widget();
-            delete child;
-        }
-
-        if (m_Counters){
-            foreach(Counter* c, *m_Counters){
-                CounterWidget* w = new CounterWidget(this, c, m_Settings);
-                ui->frmContatori->layout()->addWidget(w);
-            }
-        }
+        RefreshCounterWidgets();
         SetUpdatedLabel(m_Settings->LastUpdated);
     }
 }
@@ -329,3 +373,4 @@ void MainWindow::SetUpdatedLabel(QDateTime date)
         ui->lblUpdated->setText(QString(tr("Aggiornato: %1").arg(date.toString("dd/MM/yyyy hh:mm"))));
     }
 }
+
