@@ -16,15 +16,17 @@ QString SaldoPunti::ToString()
                                     .arg(Aggiornamento.toString("dd/MM/yyyy"));
 }
 
-void SaldoPunti::FromString(QString string)
+bool SaldoPunti::FromString(QString string)
 {
     QStringList list = string.split(';');
     if (list.count() < 5)
-        return;
+        return false;
 
     Punti = list.at(0).toInt();
     PuntiInScadenza = list.at(1).toInt();
     AnnoPuntiInScadenza = list.at(2).toInt();
     Scadenza = QDate::fromString(list.at(3), "dd/MM/yyyy");
     Aggiornamento = QDate::fromString(list.at(4), "dd/MM/yyyy");
+
+    return true;
 }
