@@ -7,9 +7,12 @@
 Settings::Settings(QObject *parent) :
     QObject(parent)
 {
+    StyleSheetName = "Default";
+    ShowStandardCounters = false;
     ShowPercentage = true;
     LogXml = false;
-    ShowLastData = true;
+    SmsSent = 0;
+    ShowLastData = true;    
     LastCredito = 0;
     LastSaldoPunti = NULL;
     LastCounters = NULL;
@@ -18,12 +21,12 @@ Settings::Settings(QObject *parent) :
 QString Settings::GetConfigName()
 {
 #ifdef Q_WS_MAEMO_5
-    QString folder = QString("%1/.vodafone190").arg(CommonStatic::GetHomeFolder());
+    QString folder = CommonStatic::GetSettingsFolder();
     if (!QDir().exists(folder))
         QDir().mkdir(folder);
     return QString("%1/settings.conf").arg(folder);
 #else
-    return QString("%1/settings.conf").arg(QCoreApplication::applicationDirPath());
+    return QString("%1/settings.conf").arg(CommonStatic::GetSettingsFolder());
 #endif
 }
 
@@ -33,11 +36,15 @@ bool Settings::Save()
 
     settings->beginGroup("Main");
 
+    settings->setValue("stylesheet", StyleSheetName);
     settings->setValue("username", Username);
     settings->setValue("password", Password);
     settings->setValue("logxml", LogXml);
     settings->setValue("showpercentage", ShowPercentage);
+    settings->setValue("showstandardcounters", ShowStandardCounters);
 
+    settings->setValue("smsdate", SmsDate.toString("dd/MM/yyyy"));
+    settings->setValue("smssent", SmsSent);
     settings->setValue("showlastdata", ShowLastData);
     settings->setValue("lastupdated", LastUpdated);
     settings->setValue("lastcredito", LastCredito);
@@ -69,15 +76,19 @@ bool Settings::Load()
 
     settings->beginGroup("Main");
 
+    StyleSheetName = settings->value("stylesheet", "default").toString();
     Username = settings->value("username").toString();
     Password = settings->value("password").toString();
-    LogXml = settings->value("logxml").toBool();
-    ShowPercentage = settings->value("showpercentage").toBool();
+    LogXml = settings->value("logxml", false).toBool();
+    ShowPercentage = settings->value("showpercentage", true).toBool();
+    ShowStandardCounters = settings->value("showstandardcounters", false).toBool();
 
-    ShowLastData = settings->value("showlastdata").toBool();
+    SmsDate = settings->value("smsdate").toDate();
+    SmsSent = settings->value("smssent").toInt();
+    ShowLastData = settings->value("showlastdata", true).toBool();
     LastUpdated = settings->value("lastupdated").toDateTime();
-    LastCredito = settings->value("lastcredito").toFloat();
-    LastValuta = settings->value("lastvaluta").toString();
+    LastCredito = settings->value("lastcredito", 0).toFloat();
+    LastValuta = settings->value("lastvaluta", "E").toString();
     QString saldo = settings->value("lastsaldopunti").toString();
     LastSaldoPunti = new SaldoPunti();
     LastSaldoPunti->FromString(saldo);
