@@ -12,11 +12,17 @@ class Settings : public QObject
 public:
     explicit Settings(QObject *parent = 0);
 
+    QString StyleSheetName;
     QString Username;
     QString Password;
 
     bool LogXml;
     bool ShowPercentage;
+    bool ShowStandardCounters;
+
+    //Sms sent counter:
+    QDate SmsDate;
+    int SmsSent;
 
     //Last data retrieved:
     QDateTime LastUpdated;
