@@ -20,10 +20,12 @@ private:
     Ui::SettingsWindow *ui;
 
     Settings* m_Settings;
+    QStringList GetStyleSheets();
 
 private slots:
     void CancelSlot();
     void SaveSlot();
+    void StyleSlot(int index);
 };
 
 #endif // SETTINGSWINDOW_H
