@@ -26,7 +26,7 @@ SimsWindow::SimsWindow(QWidget *parent, QStringList* sims) :
         ui->scrollAreaWidgetContents->setLayout(layout);
         layout->setAlignment(Qt::AlignTop);
         layout->setSpacing(0);
-        layout->setMargin(3);
+        layout->setContentsMargins(3,3,3,3);
     }
 
     foreach(QString sim, *sims){
