@@ -7,12 +7,19 @@
 #include "captchawindow.h"
 #include "contactswindow.h"
 
-SmsWindow::SmsWindow(QWidget *parent, VodafoneWidget* vodafone) :
+SmsWindow::SmsWindow(QWidget *parent, VodafoneWidget* vodafone, Settings* settings) :
     QDialog(parent),
     ui(new Ui::SmsWindow)
 {
     ui->setupUi(this);
 
+#ifdef Q_OS_SYMBIAN
+    setWindowTitle(QString(tr("SMS (%1/10)")).arg(settings->SmsSent));
+#else
+    setWindowTitle(QString(tr("Vodafone 190 - SMS (%1/10)")).arg(settings->SmsSent));
+#endif
+
+    m_Settings = settings;
     m_Vodafone = vodafone;
     connect(ui->btnContacts, SIGNAL(clicked()), this, SLOT(ContactsSlot()));
     connect(ui->btnSend, SIGNAL(clicked()), this, SLOT(SendSlot()));    
@@ -39,7 +46,7 @@ SmsWindow::SmsWindow(QWidget *parent, VodafoneWidget* vodafone) :
     connect(softKey, SIGNAL(triggered()), this, SLOT(CancelSlot()));
     addAction(softKey);
 #else
-    QRegExp re("+?[0-9]*");
+    QRegExp re("[0-9]*");
     QRegExpValidator *validator = new QRegExpValidator(re, this);
     ui->txtReceiver->setValidator(validator);
 #endif
@@ -55,11 +62,13 @@ SmsWindow::~SmsWindow()
 void SmsWindow::ContactsSlot()
 {
     ContactsWindow* frm = new ContactsWindow(this);
-    frm->show();
-    frm->Init();
 #if defined(Q_OS_SYMBIAN)
     frm->showMaximized();
+#else
+    frm->show();
 #endif
+
+    frm->Init();
     if (frm->exec() == QDialog::Accepted)
         ui->txtReceiver->setText(frm->GetSelectedNumber());
     delete frm;
@@ -114,15 +123,23 @@ void SmsWindow::SendSlot()
 #endif
 
                 CaptchaWindow* frm = new CaptchaWindow(this, pixmap);
-#if defined(Q_OS_SYMBIAN)
+#ifdef Q_OS_SYMBIAN
     frm->showMaximized();
 #endif
                 if (frm->exec() == QDialog::Accepted)
                     captcha = frm->GetCaptcha();
+                delete frm;
             }
             if (!captcha.isEmpty()){
                 if (m_Vodafone->SendMessage(ui->txtReceiver->text(), ui->txtMessage->toPlainText(), captcha, &error)){
                     CommonStatic::InfoMessage(this, tr("SMS inviato"));
+
+                    if (!m_Settings->SmsDate.isValid() || m_Settings->SmsDate != QDate::currentDate()){
+                        m_Settings->SmsDate = QDate::currentDate();
+                        m_Settings->SmsSent = 0;
+                    }
+                    m_Settings->SmsSent++;
+
                     accept();
                 }else{
                     StopWait();
@@ -162,7 +179,7 @@ void SmsWindow::MessageChangedSlot()
 {
     int chars = ui->txtMessage->toPlainText().length();
     ui->lblCharacters->setText(QString("%1/360").arg(chars));
-    if (chars < 0)
+    if (chars > 360)
         ui->lblCharacters->setStyleSheet("color: red;");
     else
         ui->lblCharacters->setStyleSheet("color: black;");
