@@ -2,6 +2,7 @@
 #define SMSWINDOW_H
 
 #include <QDialog>
+#include "settings.h"
 #include "vodafonewidget.h"
 
 namespace Ui {
@@ -13,11 +14,12 @@ class SmsWindow : public QDialog
     Q_OBJECT
 
 public:
-    explicit SmsWindow(QWidget *parent = 0, VodafoneWidget* vodafone=0);
+    explicit SmsWindow(QWidget *parent = 0, VodafoneWidget* vodafone=0, Settings* settings=0);
     ~SmsWindow();
 
 private:
     Ui::SmsWindow *ui;
+    Settings* m_Settings;
     VodafoneWidget* m_Vodafone;
 
     void StopWait();
