@@ -1,11 +1,14 @@
 #include "counterwidget.h"
 #include "commonstatic.h"
+#include "qtitlelabel.h"
 
 CounterWidget::CounterWidget(QWidget *parent, Counter* counter, Settings* settings) :
     QScrollArea(parent)
-{
+{    
+
     m_Counter = counter;
 
+    m_Bar = NULL;
     setFrameStyle(QFrame::NoFrame | QFrame::Plain);
     setWidgetResizable(true);
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -13,13 +16,12 @@ CounterWidget::CounterWidget(QWidget *parent, Counter* counter, Settings* settin
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
 
     m_Container = new QWidget(this);
-    m_Container->setStyleSheet("color: black;");
     m_Container->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
     setWidget(m_Container);
 
     m_Layout = new QGridLayout( m_Container );
-    m_Layout->setSpacing(3);
-    m_Layout->setMargin( 0 );
+    m_Layout->setSpacing(6);
+    m_Layout->setContentsMargins(0,0,0,0);
     m_Container->setLayout(m_Layout);
 
     CreateWidgets(settings);
@@ -34,41 +36,35 @@ CounterWidget::~CounterWidget()
 void CounterWidget::CreateWidgets(Settings* settings)
 {
     int row = 0;
-    QLabel* lbl = new QLabel(this);
-    lbl->setStyleSheet("color: red;");
-    lbl->setText(m_Counter->Description);
-    m_Layout->addWidget(lbl, row, 0, 1, 2);
+    QTitleLabel* titleLbl = new QTitleLabel(this);
+    titleLbl->setWordWrap(true);
+    titleLbl->setText(m_Counter->Description);
+    m_Layout->addWidget(titleLbl, row, 0, 1, 2);
 
     row++;
-    QProgressBar* bar = new QProgressBar(this);
-    bar->setMaximumHeight(30);
-    bar->setMinimum(0);
+    m_Bar = new QProgressBar(this);
+    m_Bar->setMinimum(0);
     if (m_Counter->Soglia > 0)
-        bar->setMaximum(m_Counter->Soglia);
+        m_Bar->setMaximum(m_Counter->Soglia);
     else
-        bar->setMaximum(100);
-    bar->setValue(m_Counter->Utilizzato);
-    bar->setTextVisible(false);
-    bar->setStyleSheet("QProgressBar:horizontal { \
-                        border: 1px solid gray; \
-                        border-radius: 3px; \
-                        background: white; \
-                        padding: 1px; \
-                        text-align: center; \
-                        } \
-                        QProgressBar::chunk:horizontal { \
-                        background: qlineargradient(x1: 0, y1: 0.5, x2: 1, y2: 0.5, stop: 0 red, stop: 1 white); \
-                        }");
-    if (settings && settings->ShowPercentage)
-        bar->setTextVisible(true);
-
-    m_Layout->addWidget(bar, row, 0, 1, 2);
+        m_Bar->setMaximum(100);
+    m_Bar->setValue(m_Counter->Utilizzato);
+    if (settings)
+        SetPercentageVisible(settings->ShowPercentage);
+    m_Layout->addWidget(m_Bar, row, 0, 1, 2);
 
+    QLabel* lbl = NULL;
     row++;
     if (m_Counter->Unita == "K"){
         lbl = new QLabel(this);
         lbl->setText(QString(tr("Traff. utilizzato: %1 / %2")).arg(CommonStatic::FormatKBytes(m_Counter->Utilizzato)).arg(CommonStatic::FormatKBytes(m_Counter->Soglia)));
 
+        m_Layout->addWidget(lbl, row, 0, 1, 1);
+    }else if (m_Counter->Unita == "A"){
+        QString valuta = QChar(8364);
+        lbl = new QLabel(this);
+        lbl->setText(QString(tr("Traff. utilizzato: %1 %3/ %2 %3")).arg(m_Counter->Utilizzato, 4, 'f', 2).arg(m_Counter->Soglia, 4, 'f', 2).arg(valuta));
+
         m_Layout->addWidget(lbl, row, 0, 1, 1);
     }else if (m_Counter->Unita == "Y"){
         lbl = new QLabel(this);
@@ -115,3 +111,9 @@ QString CounterWidget::ToHourMinutes(int seconds)
     QString s;
     return QString("%1:%2").arg(hh, 2, 10, QChar('0')).arg(mm, 2, 10, QChar('0'));
 }
+
+void CounterWidget::SetPercentageVisible(bool visible)
+{
+    if (m_Bar != NULL)
+        m_Bar->setTextVisible(visible);
+}
