@@ -15,11 +15,15 @@ class CounterWidget : public QScrollArea
 public:
     explicit CounterWidget(QWidget *parent = 0, Counter* counter=0, Settings* settings=0);
     ~CounterWidget();
+
+    void SetPercentageVisible(bool visible);
+
 private:
     Counter* m_Counter;
 
     QWidget* m_Container;
     QGridLayout* m_Layout;
+    QProgressBar* m_Bar;
 
     void CreateWidgets(Settings* settings);
     QString ToHourMinutes(int seconds);
